# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at https://mozilla.org/MPL/2.0/.

from typing import Mapping, Optional

from saturn_sync.protocol.v1.saturnsync_pb2 import Context, Filter


class Task:
    name: str
    auto_merge: bool = False
    auto_merge_after_seconds: int = 0
    branch_name: str = ""
    change_limit: Optional[int] = None
    commit_message: str = ""
    create_only: bool = False
    disabled: bool = False
    filters: list[Filter] = []
    keep_branch_after_merge: bool = False
    labels: list[str] = []
    merge_once: bool = False
    pr_body: str = ""
    pr_title: str = ""

    def init(self, config: Mapping[str, str]) -> None:
        pass

    def apply(self, ctx: Context) -> None:
        raise NotImplementedError("Task does not implement method apply()")

    def filter(self, ctx: Context) -> bool:
        raise NotImplementedError("Task does not implement method filter()")

    def on_pr_closed(self, ctx: Context):
        pass

    def on_pr_created(self, ctx: Context):
        pass

    def on_pr_merged(self, ctx: Context):
        pass



# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at https://mozilla.org/MPL/2.0/.

import collections.abc
import contextlib
import errno
import json
import os
import random
import socket
import sys
import time
from concurrent import futures
from typing import Iterable, Iterator

import grpc
from grpc_health.v1 import health_pb2, health_pb2_grpc
from grpc_health.v1.health import HealthServicer

from saturn_sync.plugin import grpc_controller_pb2_grpc
from saturn_sync.protocol.v1 import saturnsync_pb2, saturnsync_pb2_grpc
from saturn_sync.task import Task

BIND_IP: str = "127.0.0.1"


class Config(collections.abc.Mapping):
    def __init__(self, data: dict[str, str]):
        self._data = data

    def __getitem__(self, item: str) -> str:
        item_lower = item.lower()
        return self._data.get(item_lower, "")

    def __iter__(self):
        return self._data.__iter__()

    def __len__(self):
        return self._data.__len__()


@contextlib.contextmanager
def in_checkout_dir(d: str) -> Iterator[None]:
    current = os.getcwd()
    os.chdir(d)
    try:
        yield
    finally:
        os.chdir(current)


class TaskService(saturnsync_pb2_grpc.TaskServiceServicer):
    def __init__(self, tasks: Iterable[Task]):
        self._tasks: dict[str, Task] = {}
        for t in tasks:
            self._tasks[t.name] = t

    def ExecuteActions(
        self, request: saturnsync_pb2.ExecuteActionsRequest, context
    ) -> saturnsync_pb2.ExecuteActionsResponse:
        try:
            with in_checkout_dir(request.path):
                task = self._tasks.get(request.task_name, None)
                if task is None:
                    return saturnsync_pb2.ExecuteActionsResponse(
                        error=f"unknown task {request.task_name}"
                    )

                task.apply(ctx=request.context)
        except Exception as e:
            return saturnsync_pb2.ExecuteActionsResponse(
                error=f"exception during apply of {request.task_name}: {e}"
            )

        return saturnsync_pb2.ExecuteActionsResponse(error=None)

    def ExecuteFilters(
        self, request: saturnsync_pb2.ExecuteFiltersRequest, context
    ) -> saturnsync_pb2.ExecuteFiltersResponse:
        try:
            task = self._tasks.get(request.task_name, None)
            if task is None:
                return saturnsync_pb2.ExecuteFiltersResponse(
                    match=False, error=f"unknown task {request.task_name}"
                )

            result = task.filter(ctx=request.context)
            return saturnsync_pb2.ExecuteFiltersResponse(match=result, error=None)
        except Exception as e:
            return saturnsync_pb2.ExecuteFiltersResponse(
                match=False,
                error=f"exception during filtering of {request.task_name}: {e}",
            )

    def ListTasks(
        self, request: saturnsync_pb2.ListTasksRequest, context
    ) -> saturnsync_pb2.ListTasksResponse:
        try:
            config = Config(data=json.loads(request.custom_config))
            proto_tasks: list[saturnsync_pb2.Task] = []
            for t in self._tasks.values():
                t.init(config)
                proto_tasks.append(_to_proto_task(t))

            return saturnsync_pb2.ListTasksResponse(tasks=proto_tasks)
        except Exception as e:
            return saturnsync_pb2.ListTasksResponse(error=f"cannot list tasks: {e}")

    def OnPrClosed(
        self, request: saturnsync_pb2.OnPrClosedRequest, context
    ) -> saturnsync_pb2.OnPrClosedResponse:
        try:
            task = self._tasks.get(request.task_name, None)
            if task is None:
                return saturnsync_pb2.OnPrClosedResponse(
                    error=f"unknown task {request.task_name}"
                )

            task.on_pr_closed(request.context)
            return saturnsync_pb2.OnPrClosedResponse(error=None)
        except Exception as e:
            return saturnsync_pb2.OnPrClosedResponse(
                error=f"exception during execution: {e}"
            )

    def OnPrCreated(
        self, request: saturnsync_pb2.OnPrCreatedRequest, context
    ) -> saturnsync_pb2.OnPrCreatedResponse:
        try:
            task = self._tasks.get(request.task_name, None)
            if task is None:
                return saturnsync_pb2.OnPrCreatedResponse(
                    error=f"unknown task {request.task_name}"
                )

            task.on_pr_created(request.context)
            return saturnsync_pb2.OnPrCreatedResponse(error=None)
        except Exception as e:
            return saturnsync_pb2.OnPrCreatedResponse(
                error=f"exception during execution: {e}"
            )

    def OnPrMerged(
        self, request: saturnsync_pb2.OnPrMergedRequest, context
    ) -> saturnsync_pb2.OnPrMergedResponse:
        try:
            task = self._tasks.get(request.task_name, None)
            if task is None:
                return saturnsync_pb2.OnPrMergedResponse(
                    error=f"unknown task {request.task_name}"
                )

            task.on_pr_merged(request.context)
            return saturnsync_pb2.OnPrMergedResponse(error=None)
        except Exception as e:
            return saturnsync_pb2.OnPrMergedResponse(
                error=f"exception during execution: {e}"
            )


class GRPCController(grpc_controller_pb2_grpc.GRPCControllerServicer):
    def __init__(self):
        self.is_shut_down = False

    def Shutdown(self, request, context):
        self.is_shut_down = True


def serve(port: int, shutdown: GRPCController, tasks: Iterable[Task]):
    server = grpc.server(futures.ThreadPoolExecutor(max_workers=10))
    server.add_insecure_port(f"{BIND_IP}:{port}")

    saturnsync_pb2_grpc.add_TaskServiceServicer_to_server(
        servicer=TaskService(tasks), server=server
    )

    grpc_controller_pb2_grpc.add_GRPCControllerServicer_to_server(
        servicer=shutdown, server=server
    )

    health = HealthServicer()
    health.set("plugin", health_pb2.HealthCheckResponse.ServingStatus.Value("SERVING"))
    health_pb2_grpc.add_HealthServicer_to_server(servicer=health, server=server)
    server.start()
    return server


def serve_tasks(*tasks: Task) -> None:
    port = _find_open_port()
    grpc_controller = GRPCController()
    server = serve(port=port, shutdown=grpc_controller, tasks=tasks)
    print(f"1|1|tcp|{BIND_IP}:{port}|grpc")
    sys.stdout.flush()
    try:
        while True:
            time.sleep(0.1)
            if grpc_controller.is_shut_down is True:
                server.stop(0)
                sys.exit(0)
    except KeyboardInterrupt:
        server.stop(0)


def _find_open_port() -> int:
    while True:
        port = random.randrange(start=11000, stop=12000)
        s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
        try:
            s.bind((BIND_IP, port))
            return port
        except socket.error as e:
            if e.errno != errno.EADDRINUSE:
                raise e
        finally:
            if s is not None:
                s.close()


def _to_proto_task(task: Task) -> saturnsync_pb2.Task:
    return saturnsync_pb2.Task(
        name=task.name,
        auto_merge=task.auto_merge,
        auto_merge_after_seconds=task.auto_merge_after_seconds,
        branch_name=task.branch_name,
        change_limit=task.change_limit,
        commit_message=task.commit_message,
        create_only=task.create_only,
        disabled=task.disabled,
        filters=task.filters,
        keep_branch_after_merge=task.keep_branch_after_merge,
        labels=task.labels,
        merge_once=task.merge_once,
        pr_body=task.pr_body,
        pr_title=task.pr_title,
    )



# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at https://mozilla.org/MPL/2.0/.

from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ExecuteActionsRequest(_message.Message):
    __slots__ = ("task_name", "path", "context")
    TASK_NAME_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    task_name: str
    path: str
    context: Context
    def __init__(self, task_name: _Optional[str] = ..., path: _Optional[str] = ..., context: _Optional[_Union[Context, _Mapping]] = ...) -> None: ...

class ExecuteActionsResponse(_message.Message):
    __slots__ = ("error",)
    ERROR_FIELD_NUMBER: _ClassVar[int]
    error: str
    def __init__(self, error: _Optional[str] = ...) -> None: ...

class ExecuteFiltersRequest(_message.Message):
    __slots__ = ("task_name", "context")
    TASK_NAME_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    task_name: str
    context: Context
    def __init__(self, task_name: _Optional[str] = ..., context: _Optional[_Union[Context, _Mapping]] = ...) -> None: ...

class ExecuteFiltersResponse(_message.Message):
    __slots__ = ("match", "error")
    MATCH_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    match: bool
    error: str
    def __init__(self, match: bool = ..., error: _Optional[str] = ...) -> None: ...

class ListTasksRequest(_message.Message):
    __slots__ = ("custom_config",)
    CUSTOM_CONFIG_FIELD_NUMBER: _ClassVar[int]
    custom_config: bytes
    def __init__(self, custom_config: _Optional[bytes] = ...) -> None: ...

class ListTasksResponse(_message.Message):
    __slots__ = ("tasks", "error")
    TASKS_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    tasks: _containers.RepeatedCompositeFieldContainer[Task]
    error: str
    def __init__(self, tasks: _Optional[_Iterable[_Union[Task, _Mapping]]] = ..., error: _Optional[str] = ...) -> None: ...

class Action(_message.Message):
    __slots__ = ("file",)
    FILE_FIELD_NUMBER: _ClassVar[int]
    file: ActionFile
    def __init__(self, file: _Optional[_Union[ActionFile, _Mapping]] = ...) -> None: ...

class ActionFile(_message.Message):
    __slots__ = ("content", "mode", "path", "state")
    CONTENT_FIELD_NUMBER: _ClassVar[int]
    MODE_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    content: str
    mode: str
    path: str
    state: str
    def __init__(self, content: _Optional[str] = ..., mode: _Optional[str] = ..., path: _Optional[str] = ..., state: _Optional[str] = ...) -> None: ...

class Context(_message.Message):
    __slots__ = ("repository",)
    REPOSITORY_FIELD_NUMBER: _ClassVar[int]
    repository: Repository
    def __init__(self, repository: _Optional[_Union[Repository, _Mapping]] = ...) -> None: ...

class Repository(_message.Message):
    __slots__ = ("full_name", "clone_url_http", "clone_url_ssh", "web_url")
    FULL_NAME_FIELD_NUMBER: _ClassVar[int]
    CLONE_URL_HTTP_FIELD_NUMBER: _ClassVar[int]
    CLONE_URL_SSH_FIELD_NUMBER: _ClassVar[int]
    WEB_URL_FIELD_NUMBER: _ClassVar[int]
    full_name: str
    clone_url_http: str
    clone_url_ssh: str
    web_url: str
    def __init__(self, full_name: _Optional[str] = ..., clone_url_http: _Optional[str] = ..., clone_url_ssh: _Optional[str] = ..., web_url: _Optional[str] = ...) -> None: ...

class Filter(_message.Message):
    __slots__ = ("file", "line_in_file", "repository_name", "reverse")
    FILE_FIELD_NUMBER: _ClassVar[int]
    LINE_IN_FILE_FIELD_NUMBER: _ClassVar[int]
    REPOSITORY_NAME_FIELD_NUMBER: _ClassVar[int]
    REVERSE_FIELD_NUMBER: _ClassVar[int]
    file: FilterFile
    line_in_file: FilterLineInFile
    repository_name: FilterRepositoryName
    reverse: bool
    def __init__(self, file: _Optional[_Union[FilterFile, _Mapping]] = ..., line_in_file: _Optional[_Union[FilterLineInFile, _Mapping]] = ..., repository_name: _Optional[_Union[FilterRepositoryName, _Mapping]] = ..., reverse: bool = ...) -> None: ...

class FilterLineInFile(_message.Message):
    __slots__ = ("path", "search")
    PATH_FIELD_NUMBER: _ClassVar[int]
    SEARCH_FIELD_NUMBER: _ClassVar[int]
    path: str
    search: str
    def __init__(self, path: _Optional[str] = ..., search: _Optional[str] = ...) -> None: ...

class FilterFile(_message.Message):
    __slots__ = ("path",)
    PATH_FIELD_NUMBER: _ClassVar[int]
    path: str
    def __init__(self, path: _Optional[str] = ...) -> None: ...

class FilterRepositoryName(_message.Message):
    __slots__ = ("names",)
    NAMES_FIELD_NUMBER: _ClassVar[int]
    names: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, names: _Optional[_Iterable[str]] = ...) -> None: ...

class OnPrClosedRequest(_message.Message):
    __slots__ = ("task_name", "context")
    TASK_NAME_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    task_name: str
    context: Context
    def __init__(self, task_name: _Optional[str] = ..., context: _Optional[_Union[Context, _Mapping]] = ...) -> None: ...

class OnPrClosedResponse(_message.Message):
    __slots__ = ("error",)
    ERROR_FIELD_NUMBER: _ClassVar[int]
    error: str
    def __init__(self, error: _Optional[str] = ...) -> None: ...

class OnPrCreatedRequest(_message.Message):
    __slots__ = ("task_name", "context")
    TASK_NAME_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    task_name: str
    context: Context
    def __init__(self, task_name: _Optional[str] = ..., context: _Optional[_Union[Context, _Mapping]] = ...) -> None: ...

class OnPrCreatedResponse(_message.Message):
    __slots__ = ("error",)
    ERROR_FIELD_NUMBER: _ClassVar[int]
    error: str
    def __init__(self, error: _Optional[str] = ...) -> None: ...

class OnPrMergedRequest(_message.Message):
    __slots__ = ("task_name", "context")
    TASK_NAME_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    task_name: str
    context: Context
    def __init__(self, task_name: _Optional[str] = ..., context: _Optional[_Union[Context, _Mapping]] = ...) -> None: ...

class OnPrMergedResponse(_message.Message):
    __slots__ = ("error",)
    ERROR_FIELD_NUMBER: _ClassVar[int]
    error: str
    def __init__(self, error: _Optional[str] = ...) -> None: ...

class Task(_message.Message):
    __slots__ = ("name", "auto_merge", "auto_merge_after_seconds", "branch_name", "change_limit", "commit_message", "create_only", "disabled", "keep_branch_after_merge", "labels", "merge_once", "pr_body", "pr_title", "filters", "actions")
    NAME_FIELD_NUMBER: _ClassVar[int]
    AUTO_MERGE_FIELD_NUMBER: _ClassVar[int]
    AUTO_MERGE_AFTER_SECONDS_FIELD_NUMBER: _ClassVar[int]
    BRANCH_NAME_FIELD_NUMBER: _ClassVar[int]
    CHANGE_LIMIT_FIELD_NUMBER: _ClassVar[int]
    COMMIT_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    CREATE_ONLY_FIELD_NUMBER: _ClassVar[int]
    DISABLED_FIELD_NUMBER: _ClassVar[int]
    KEEP_BRANCH_AFTER_MERGE_FIELD_NUMBER: _ClassVar[int]
    LABELS_FIELD_NUMBER: _ClassVar[int]
    MERGE_ONCE_FIELD_NUMBER: _ClassVar[int]
    PR_BODY_FIELD_NUMBER: _ClassVar[int]
    PR_TITLE_FIELD_NUMBER: _ClassVar[int]
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    ACTIONS_FIELD_NUMBER: _ClassVar[int]
    name: str
    auto_merge: bool
    auto_merge_after_seconds: int
    branch_name: str
    change_limit: int
    commit_message: str
    create_only: bool
    disabled: bool
    keep_branch_after_merge: bool
    labels: _containers.RepeatedScalarFieldContainer[str]
    merge_once: bool
    pr_body: str
    pr_title: str
    filters: _containers.RepeatedCompositeFieldContainer[Filter]
    actions: _containers.RepeatedCompositeFieldContainer[Action]
    def __init__(self, name: _Optional[str] = ..., auto_merge: bool = ..., auto_merge_after_seconds: _Optional[int] = ..., branch_name: _Optional[str] = ..., change_limit: _Optional[int] = ..., commit_message: _Optional[str] = ..., create_only: bool = ..., disabled: bool = ..., keep_branch_after_merge: bool = ..., labels: _Optional[_Iterable[str]] = ..., merge_once: bool = ..., pr_body: _Optional[str] = ..., pr_title: _Optional[str] = ..., filters: _Optional[_Iterable[_Union[Filter, _Mapping]]] = ..., actions: _Optional[_Iterable[_Union[Action, _Mapping]]] = ...) -> None: ...



# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at https://mozilla.org/MPL/2.0/.

from saturn_sync.protocol.v1.saturnsync_pb2 import (
    Context,
    Filter,
    FilterFile,
    FilterLineInFile,
    FilterRepositoryName,
)
from saturn_sync.sdk import serve_tasks
from saturn_sync.task import Task

__all__ = [
    "Context",
    "Filter",
    "FilterFile",
    "FilterLineInFile",
    "FilterRepositoryName",
    "Task",
    "serve_tasks",
]



# -*- coding: utf-8 -*-
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at https://mozilla.org/MPL/2.0/.

# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: saturn_sync/protocol/v1/saturnsync.proto
# Protobuf Python Version: 4.25.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(saturn_sync/protocol/v1/saturnsync.proto\x12\x0bprotocol.v1\"x\n\x15\x45xecuteActionsRequest\x12\x1b\n\ttask_name\x18\x01 \x01(\tR\x08taskName\x12\x12\n\x04path\x18\x02 \x01(\tR\x04path\x12.\n\x07\x63ontext\x18\x03 \x01(\x0b\x32\x14.protocol.v1.ContextR\x07\x63ontext\"=\n\x16\x45xecuteActionsResponse\x12\x19\n\x05\x65rror\x18\x01 \x01(\tH\x00R\x05\x65rror\x88\x01\x01\x42\x08\n\x06_error\"d\n\x15\x45xecuteFiltersRequest\x12\x1b\n\ttask_name\x18\x01 \x01(\tR\x08taskName\x12.\n\x07\x63ontext\x18\x02 \x01(\x0b\x32\x14.protocol.v1.ContextR\x07\x63ontext\"S\n\x16\x45xecuteFiltersResponse\x12\x14\n\x05match\x18\x01 \x01(\x08R\x05match\x12\x19\n\x05\x65rror\x18\x02 \x01(\tH\x00R\x05\x65rror\x88\x01\x01\x42\x08\n\x06_error\"7\n\x10ListTasksRequest\x12#\n\rcustom_config\x18\x01 \x01(\x0cR\x0c\x63ustomConfig\"a\n\x11ListTasksResponse\x12\'\n\x05tasks\x18\x01 \x03(\x0b\x32\x11.protocol.v1.TaskR\x05tasks\x12\x19\n\x05\x65rror\x18\x02 \x01(\tH\x00R\x05\x65rror\x88\x01\x01\x42\x08\n\x06_error\"C\n\x06\x41\x63tion\x12\x30\n\x04\x66ile\x18\x01 \x01(\x0b\x32\x17.protocol.v1.ActionFileH\x00R\x04\x66ile\x88\x01\x01\x42\x07\n\x05_file\"r\n\nActionFile\x12\x18\n\x07\x63ontent\x18\x01 \x01(\tR\x07\x63ontent\x12\x17\n\x04mode\x18\x02 \x01(\tH\x00R\x04mode\x88\x01\x01\x12\x12\n\x04path\x18\x03 \x01(\tR\x04path\x12\x14\n\x05state\x18\x04 \x01(\tR\x05stateB\x07\n\x05_mode\"B\n\x07\x43ontext\x12\x37\n\nrepository\x18\x01 \x01(\x0b\x32\x17.protocol.v1.RepositoryR\nrepository\"\x8c\x01\n\nRepository\x12\x1b\n\tfull_name\x18\x01 \x01(\tR\x08\x66ullName\x12$\n\x0e\x63lone_url_http\x18\x02 \x01(\tR\x0c\x63loneUrlHttp\x12\"\n\rclone_url_ssh\x18\x03 \x01(\tR\x0b\x63loneUrlSsh\x12\x17\n\x07web_url\x18\x04 \x01(\tR\x06webUrl\"\xaa\x02\n\x06\x46ilter\x12\x30\n\x04\x66ile\x18\x01 \x01(\x0b\x32\x17.protocol.v1.FilterFileH\x00R\x04\x66ile\x88\x01\x01\x12\x44\n\x0cline_in_file\x18\x02 \x01(\x0b\x32\x1d.protocol.v1.FilterLineInFileH\x01R\nlineInFile\x88\x01\x01\x12O\n\x0frepository_name\x18\x03 \x01(\x0b\x32!.protocol.v1.FilterRepositoryNameH\x02R\x0erepositoryName\x88\x01\x01\x12\x1d\n\x07reverse\x18\x04 \x01(\x08H\x03R\x07reverse\x88\x01\x01\x42\x07\n\x05_fileB\x0f\n\r_line_in_fileB\x12\n\x10_repository_nameB\n\n\x08_reverse\">\n\x10\x46ilterLineInFile\x12\x12\n\x04path\x18\x01 \x01(\tR\x04path\x12\x16\n\x06search\x18\x02 \x01(\tR\x06search\" \n\nFilterFile\x12\x12\n\x04path\x18\x01 \x01(\tR\x04path\",\n\x14\x46ilterRepositoryName\x12\x14\n\x05names\x18\x01 \x03(\tR\x05names\"`\n\x11OnPrClosedRequest\x12\x1b\n\ttask_name\x18\x01 \x01(\tR\x08taskName\x12.\n\x07\x63ontext\x18\x02 \x01(\x0b\x32\x14.protocol.v1.ContextR\x07\x63ontext\"9\n\x12OnPrClosedResponse\x12\x19\n\x05\x65rror\x18\x01 \x01(\tH\x00R\x05\x65rror\x88\x01\x01\x42\x08\n\x06_error\"a\n\x12OnPrCreatedRequest\x12\x1b\n\ttask_name\x18\x01 \x01(\tR\x08taskName\x12.\n\x07\x63ontext\x18\x02 \x01(\x0b\x32\x14.protocol.v1.ContextR\x07\x63ontext\":\n\x13OnPrCreatedResponse\x12\x19\n\x05\x65rror\x18\x01 \x01(\tH\x00R\x05\x65rror\x88\x01\x01\x42\x08\n\x06_error\"`\n\x11OnPrMergedRequest\x12\x1b\n\ttask_name\x18\x01 \x01(\tR\x08taskName\x12.\n\x07\x63ontext\x18\x02 \x01(\x0b\x32\x14.protocol.v1.ContextR\x07\x63ontext\"9\n\x12OnPrMergedResponse\x12\x19\n\x05\x65rror\x18\x01 \x01(\tH\x00R\x05\x65rror\x88\x01\x01\x42\x08\n\x06_error\"\x92\x06\n\x04Task\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\"\n\nauto_merge\x18\x02 \x01(\x08H\x00R\tautoMerge\x88\x01\x01\x12<\n\x18\x61uto_merge_after_seconds\x18\x03 \x01(\x05H\x01R\x15\x61utoMergeAfterSeconds\x88\x01\x01\x12$\n\x0b\x62ranch_name\x18\x04 \x01(\tH\x02R\nbranchName\x88\x01\x01\x12&\n\x0c\x63hange_limit\x18\x05 \x01(\x05H\x03R\x0b\x63hangeLimit\x88\x01\x01\x12*\n\x0e\x63ommit_message\x18\x06 \x01(\tH\x04R\rcommitMessage\x88\x01\x01\x12$\n\x0b\x63reate_only\x18\x07 \x01(\x08H\x05R\ncreateOnly\x88\x01\x01\x12\x1f\n\x08\x64isabled\x18\x08 \x01(\x08H\x06R\x08\x64isabled\x88\x01\x01\x12:\n\x17keep_branch_after_merge\x18\t \x01(\x08H\x07R\x14keepBranchAfterMerge\x88\x01\x01\x12\x16\n\x06labels\x18\n \x03(\tR\x06labels\x12\"\n\nmerge_once\x18\x0b \x01(\x08H\x08R\tmergeOnce\x88\x01\x01\x12\x1c\n\x07pr_body\x18\x0c \x01(\tH\tR\x06prBody\x88\x01\x01\x12\x1e\n\x08pr_title\x18\r \x01(\tH\nR\x07prTitle\x88\x01\x01\x12-\n\x07\x66ilters\x18\x0e \x03(\x0b\x32\x13.protocol.v1.FilterR\x07\x66ilters\x12-\n\x07\x61\x63tions\x18\x0f \x03(\x0b\x32\x13.protocol.v1.ActionR\x07\x61\x63tionsB\r\n\x0b_auto_mergeB\x1b\n\x19_auto_merge_after_secondsB\x0e\n\x0c_branch_nameB\x0f\n\r_change_limitB\x11\n\x0f_commit_messageB\x0e\n\x0c_create_onlyB\x0b\n\t_disabledB\x1a\n\x18_keep_branch_after_mergeB\r\n\x0b_merge_onceB\n\n\x08_pr_bodyB\x0b\n\t_pr_title2\x8b\x04\n\x0bTaskService\x12[\n\x0e\x45xecuteActions\x12\".protocol.v1.ExecuteActionsRequest\x1a#.protocol.v1.ExecuteActionsResponse\"\x00\x12[\n\x0e\x45xecuteFilters\x12\".protocol.v1.ExecuteFiltersRequest\x1a#.protocol.v1.ExecuteFiltersResponse\"\x00\x12L\n\tListTasks\x12\x1d.protocol.v1.ListTasksRequest\x1a\x1e.protocol.v1.ListTasksResponse\"\x00\x12O\n\nOnPrClosed\x12\x1e.protocol.v1.OnPrClosedRequest\x1a\x1f.protocol.v1.OnPrClosedResponse\"\x00\x12R\n\x0bOnPrCreated\x12\x1f.protocol.v1.OnPrCreatedRequest\x1a .protocol.v1.OnPrCreatedResponse\"\x00\x12O\n\nOnPrMerged\x12\x1e.protocol.v1.OnPrMergedRequest\x1a\x1f.protocol.v1.OnPrMergedResponse\"\x00\x42o\n\x0f\x63om.protocol.v1B\x0fSaturnsyncProtoP\x01\xa2\x02\x03PXX\xaa\x02\x0bProtocol.V1\xca\x02\x0bProtocol\\V1\xe2\x02\x17Protocol\\V1\\GPBMetadata\xea\x02\x0cProtocol::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'saturn_sync.protocol.v1.saturnsync_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017com.protocol.v1B\017SaturnsyncProtoP\001\242\002\003PXX\252\002\013Protocol.V1\312\002\013Protocol\\V1\342\002\027Protocol\\V1\\GPBMetadata\352\002\014Protocol::V1'
  _globals['_EXECUTEACTIONSREQUEST']._serialized_start=57
  _globals['_EXECUTEACTIONSREQUEST']._serialized_end=177
  _globals['_EXECUTEACTIONSRESPONSE']._serialized_start=179
  _globals['_EXECUTEACTIONSRESPONSE']._serialized_end=240
  _globals['_EXECUTEFILTERSREQUEST']._serialized_start=242
  _globals['_EXECUTEFILTERSREQUEST']._serialized_end=342
  _globals['_EXECUTEFILTERSRESPONSE']._serialized_start=344
  _globals['_EXECUTEFILTERSRESPONSE']._serialized_end=427
  _globals['_LISTTASKSREQUEST']._serialized_start=429
  _globals['_LISTTASKSREQUEST']._serialized_end=484
  _globals['_LISTTASKSRESPONSE']._serialized_start=486
  _globals['_LISTTASKSRESPONSE']._serialized_end=583
  _globals['_ACTION']._serialized_start=585
  _globals['_ACTION']._serialized_end=652
  _globals['_ACTIONFILE']._serialized_start=654
  _globals['_ACTIONFILE']._serialized_end=768
  _globals['_CONTEXT']._serialized_start=770
  _globals['_CONTEXT']._serialized_end=836
  _globals['_REPOSITORY']._serialized_start=839
  _globals['_REPOSITORY']._serialized_end=979
  _globals['_FILTER']._serialized_start=982
  _globals['_FILTER']._serialized_end=1280
  _globals['_FILTERLINEINFILE']._serialized_start=1282
  _globals['_FILTERLINEINFILE']._serialized_end=1344
  _globals['_FILTERFILE']._serialized_start=1346
  _globals['_FILTERFILE']._serialized_end=1378
  _globals['_FILTERREPOSITORYNAME']._serialized_start=1380
  _globals['_FILTERREPOSITORYNAME']._serialized_end=1424
  _globals['_ONPRCLOSEDREQUEST']._serialized_start=1426
  _globals['_ONPRCLOSEDREQUEST']._serialized_end=1522
  _globals['_ONPRCLOSEDRESPONSE']._serialized_start=1524
  _globals['_ONPRCLOSEDRESPONSE']._serialized_end=1581
  _globals['_ONPRCREATEDREQUEST']._serialized_start=1583
  _globals['_ONPRCREATEDREQUEST']._serialized_end=1680
  _globals['_ONPRCREATEDRESPONSE']._serialized_start=1682
  _globals['_ONPRCREATEDRESPONSE']._serialized_end=1740
  _globals['_ONPRMERGEDREQUEST']._serialized_start=1742
  _globals['_ONPRMERGEDREQUEST']._serialized_end=1838
  _globals['_ONPRMERGEDRESPONSE']._serialized_start=1840
  _globals['_ONPRMERGEDRESPONSE']._serialized_end=1897
  _globals['_TASK']._serialized_start=1900
  _globals['_TASK']._serialized_end=2686
  _globals['_TASKSERVICE']._serialized_start=2689
  _globals['_TASKSERVICE']._serialized_end=3212
# @@protoc_insertion_point(module_scope)
